Welcome to Fabric!
==================

.. Note: README uses level 3 headers
.. include:: ../../README.rst

What is this website?
---------------------

``www.fabfile.org`` provides project information for Fabric such as the
changelog, contribution guidelines, development roadmap, news/blog, and so
forth.

Detailed conceptual and API documentation can be found at our code
documentation site, `docs.fabfile.org <http://docs.fabfile.org>`_.


.. toctree::
    :hidden:

    changelog
    changelog-v1
    FAQs <faq>
    installing
    installing-1.x
    development
    troubleshooting
    Roadmap <roadmap>
    contact

